package com.inspect.patrolresultdefault.service.impl;

import com.inspect.patrolresultdefault.domain.PatrolResultDefaultValue;
import com.inspect.patrolresultdefault.mapper.PatrolResultDefaultValueMapper;
import com.inspect.patrolresultdefault.service.IPatrolResultDefaultValueService;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

@Service
public class PatrolResultDefaultValueServiceImpl implements IPatrolResultDefaultValueService {
    private final PatrolResultDefaultValueMapper patrolResultDefaultvalueMapper;

    public PatrolResultDefaultValueServiceImpl(PatrolResultDefaultValueMapper patrolResultDefaultvalueMapper) {
        this.patrolResultDefaultvalueMapper = patrolResultDefaultvalueMapper;
    }

    public PatrolResultDefaultValue selectPatrolResultDefaultValueByResultDefaultValueId(Long resultDefaultValueId) {
        return this.patrolResultDefaultvalueMapper.selectPatrolResultDefaultValueByResultDefaultValueId(resultDefaultValueId);
    }

    public List<PatrolResultDefaultValue> selectPatrolResultDefaultvalueList(PatrolResultDefaultValue patrolResultDefaultvalue) {
        return this.patrolResultDefaultvalueMapper.selectPatrolResultDefaultValueList(patrolResultDefaultvalue);
    }

    public int insertPatrolResultDefaultValue(PatrolResultDefaultValue patrolResultDefaultvalue) {
        return this.patrolResultDefaultvalueMapper.insertPatrolResultDefaultValue(patrolResultDefaultvalue);
    }

    public int updatePatrolResultDefaultValue(PatrolResultDefaultValue patrolResultDefaultvalue) {
        return this.patrolResultDefaultvalueMapper.updatePatrolResultDefaultValue(patrolResultDefaultvalue);
    }

    public int deletePatrolResultDefaultValueByResultDefaultValueIds(Long[] resultDefaultValueIds) {
        return this.patrolResultDefaultvalueMapper.deletePatrolResultDefaultValueByResultDefaultValueIds(resultDefaultValueIds);
    }

    public int deletePatrolResultDefaultValueByResultDefaultValueId(Long resultDefaultValueId) {
        return this.patrolResultDefaultvalueMapper.deletePatrolResultDefaultValueByResultDefaultValueId(resultDefaultValueId);
    }
}
