package com.inspect.patrolresultdefault.controller;

import com.inspect.base.core.utils.poi.ExcelUtil;
import com.inspect.base.core.web.controller.BaseController;
import com.inspect.base.core.web.domain.AjaxResult;
import com.inspect.base.core.web.page.TableDataInfo;
import com.inspect.common.log.annotation.Log;
import com.inspect.common.log.enums.BizType;
import com.inspect.common.security.annotation.RequiresPermissions;
import com.inspect.patrolresultdefault.domain.PatrolResultDefaultValue;
import com.inspect.patrolresultdefault.service.IPatrolResultDefaultValueService;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

@RestController
@RequestMapping({"/patrolresultdefault"})
public class PatrolResultDefaultValueController extends BaseController {
   @Autowired
   private IPatrolResultDefaultValueService patrolResultDefaultvalueService;

   @RequiresPermissions({"patrolresultdefault:patrolresultdefault:list"})
   @GetMapping({"/list"})
   public TableDataInfo list(PatrolResultDefaultValue patrolResultDefaultvalue) {
      this.startPage();
      List<PatrolResultDefaultValue> list = this.patrolResultDefaultvalueService.selectPatrolResultDefaultvalueList(patrolResultDefaultvalue);
      return this.getDataTable(list);
   }

   @RequiresPermissions({"patrolresultdefault:patrolresultdefault:export"})
   @Log(
      title = "巡检结果默认值",
      businessType = BizType.EXPORT
   )
   @PostMapping({"/export"})
   public void export(HttpServletResponse response, PatrolResultDefaultValue patrolResultDefaultvalue) {
      List<PatrolResultDefaultValue> list = this.patrolResultDefaultvalueService.selectPatrolResultDefaultvalueList(patrolResultDefaultvalue);
      ExcelUtil<PatrolResultDefaultValue> util = new ExcelUtil(PatrolResultDefaultValue.class);
      util.exportExcel(response, list, "巡检结果默认值数据");
   }

   @RequiresPermissions({"patrolresultdefault:patrolresultdefault:query"})
   @GetMapping({"/{resultDefaultvalueId}"})
   public AjaxResult getInfo(@PathVariable("resultDefaultvalueId") Long resultDefaultvalueId) {
      return AjaxResult.success(this.patrolResultDefaultvalueService.selectPatrolResultDefaultValueByResultDefaultValueId(resultDefaultvalueId));
   }

   @RequiresPermissions({"patrolresultdefault:patrolresultdefault:add"})
   @Log(
      title = "巡检结果默认值",
      businessType = BizType.INSERT
   )
   @PostMapping
   public AjaxResult add(@RequestBody PatrolResultDefaultValue patrolResultDefaultvalue) {
      return this.toAjax(this.patrolResultDefaultvalueService.insertPatrolResultDefaultValue(patrolResultDefaultvalue));
   }

   @RequiresPermissions({"patrolresultdefault:patrolresultdefault:edit"})
   @Log(
      title = "巡检结果默认值",
      businessType = BizType.UPDATE
   )
   @PostMapping({"/edit"})
   public AjaxResult edit(@RequestBody PatrolResultDefaultValue patrolResultDefaultvalue) {
      return this.toAjax(this.patrolResultDefaultvalueService.updatePatrolResultDefaultValue(patrolResultDefaultvalue));
   }

   @RequiresPermissions({"patrolresultdefault:patrolresultdefault:remove"})
   @Log(
      title = "巡检结果默认值",
      businessType = BizType.DELETE
   )
   @PostMapping({"/remove/{resultDefaultvalueIds}"})
   public AjaxResult remove(@PathVariable Long[] resultDefaultvalueIds) {
      return this.toAjax(this.patrolResultDefaultvalueService.deletePatrolResultDefaultValueByResultDefaultValueIds(resultDefaultvalueIds));
   }
}
